@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2016 Harald Sitter <sitter@kde.org>
+    SPDX-FileCopyrightText: 2016-2021 Harald Sitter <sitter@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,12 +9,9 @@
 #include <QFile>
 
 #include <config-kcrash.h>
-
 namespace KCrash
 {
 CoreConfig::CoreConfig(const QString &path)
-    : m_supported(false)
-    , m_process(false)
 {
 #ifndef KCRASH_CORE_PATTERN_RAISE
     return; // Leave everything false unless enabled.
@@ -29,6 +26,10 @@ CoreConfig::CoreConfig(const QString &path)
     }
     m_supported = true;
     m_process = first == '|';
+
+    if (file.readLine().contains(QByteArrayLiteral("systemd-coredump"))) {
+        m_coredumpd = true;
+    }
 }
 
 bool CoreConfig::isProcess() const
@@ -36,4 +37,9 @@ bool CoreConfig::isProcess() const
     return m_supported && m_process;
 }
 
+bool CoreConfig::isCoredumpd() const
+{
+    return m_coredumpd;
+}
+
 } // namespace KCrash
