@@ -55,7 +55,11 @@ Q_LOGGING_CATEGORY(LOG_KCRASH, "kf.crash", QtInfoMsg)
 
 #if HAVE_X11
 #include <X11/Xlib.h>
-#include <qx11info_x11.h>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
+#include <QX11Info>
+#endif
 #endif
 
 #include "coreconfig_p.h"
@@ -672,10 +676,11 @@ LONG WINAPI KCrash::win32UnhandledExceptionFilter(_EXCEPTION_POINTERS *exception
 #else
 
 static pid_t startDirectly(const char *argv[]);
+
+#ifdef Q_OS_LINUX
 static int write_socket(int sock, char *buffer, int len);
 static int read_socket(int sock, char *buffer, int len);
 
-#ifdef Q_OS_LINUX
 static int openDrKonqiSocket(const QByteArray &socketpath);
 static int pollDrKonqiSocket(pid_t pid, int sockfd);
 #endif
@@ -764,6 +769,8 @@ static pid_t startDirectly(const char *argv[])
     }
 }
 
+#ifdef Q_OS_LINUX
+
 /*
  * Write 'len' bytes from 'buffer' into 'sock'.
  * returns 0 on success, -1 on failure.
@@ -808,8 +815,6 @@ static int read_socket(int sock, char *buffer, int len)
     return 0;
 }
 
-#ifdef Q_OS_LINUX
-
 static int openDrKonqiSocket(const QByteArray &socketpath)
 {
     int sockfd = socket(PF_UNIX, SOCK_STREAM, 0);
